REM #
REM # SC-SM SSL Certificates Creator (client component)
REM #
REM # This batch file facilitates the creation of the SSL certificates that are needed to setup SSL encryption for Service Manager 7.0x.
REM #
REM # Run this batch file with the fully-qualified domain name of the client machine as the first argument (%1), from the command line :
REM #
REM # \prompt>tso_cln_svlt <fully-qualified domain name>
REM #
REM # Rerun this batch file for each client machine to create a unique
REM # set of certificates for the Service Manager Eclipse or Web client.  
REM #
REM #--------------------------------------------------------------------
cls

@echo off


REM # Openssl settings
REM # 
REM # This batch file uses the openssl.conf file as input for the the openssl program. All _default values can be set according to your
REM # organisation.
REM #--------------------------------------------------------------------
set OPENSSL=openssl


REM # Java Settings
REM #
REM # set the JAVA_HOME variable to the installation path of the JRE you
REM # want to use.
REM #
REM #--------------------------------------------------------------------
set JAVA_HOME="C:\Program Files\Java\jre1.5.0_13"
set KEYTOOL=%JAVA_HOME%\bin\keytool


REM # Password settings
REM #
REM # These are the default password settings used by the openssl and
REM # keytool programs. All passwords can be changed, EXCEPT the
REM # CACERT_PASSWD, as this is the default password REM # that the SUN
REM # cacert from the JRE uses..!!
REM #
REM #--------------------------------------------------------------------
set CAROOT_PASSWD=caroot
set CACERT_PASSWD=changeit
set SERVER_KEYSTORE_PASSWD=serverkeystore
set CLIENT_KEYSTORE_PASSWD=clientkeystore
set TRUSTEDCLIENTS_KEYSTORE_PASSWD=trustedclients



######################################################################
# Only do this step if run from a different machine than the one that 
# created the server certs
######################################################################
# copy %JAVA_HOME%\lib\security\cacerts %JAVA_HOME%\lib\security\cacerts.origcopy
copy %SSL_CERT_HOME%\certs\cacerts %JAVA_HOME%\lib\security

echo Client Key and Certificate creation

REM #--------------------------------------------------------------------
REM # Client Key & Certficate generation
REM #--------------------------------------------------------------------

REM generate private client key and keystore
@echo.
@echo _________________________________________________________________________
@echo.
@echo Creating the Client keystore (%1.keystore)
@echo.
%KEYTOOL% -genkey -alias %1 -keystore key/%1.keystore -storepass %CLIENT_KEYSTORE_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.

REM generate the Client request certificate to be signed using our CA key
REM & cert
@echo.
@echo _________________________________________________________________________
@echo.
@echo Generating the Client request certificate (clientcert_request.crs)
@echo.
%KEYTOOL% -certreq -alias %1 -keystore key/%1.keystore -file crs/clientcert_request.crs -storepass %CLIENT_KEYSTORE_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.

REM sign the Client certificate using our CA
@echo.
@echo -------------------------------------
@echo.
@echo Signing the Client request certificate (scclientcert.pem)
@echo.
%OPENSSL% x509 -req -days 1095 -in crs/clientcert_request.crs -CA certs/mycacert.pem -CAkey key/cakey.pem -CAcreateserial -out certs/scclientcert.pem -passin pass:%CAROOT_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.

REM import the client certificate into the keystore
@echo.
@echo _________________________________________________________________________
@echo.
@echo Importing Client certificate into Client keystore
@echo.
%KEYTOOL% -import -trustcacerts -alias %1 -keystore key/%1.keystore -file certs/scclientcert.pem -storepass %CLIENT_KEYSTORE_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.

REM #--------------------------------------------------------------------
REM # Adding the client Certificate to Trusted Keystore
REM #--------------------------------------------------------------------

REM export client public key/certificate
@echo.
@echo _________________________________________________________________________
@echo.
@echo Exporting Client public certificate from Client keystore (clientpubkey.cert)
@echo.
%KEYTOOL% -export -alias %1 -keystore key/%1.keystore -file certs/clientpubkey.cert -storepass %CLIENT_KEYSTORE_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.

REM import public key/certificate into the keystore 
@echo.
@echo _________________________________________________________________________
@echo.
@echo Importing Client public certificate into Trustedclients keystore (trustedclients.keystore)
@echo.
%KEYTOOL% -import -alias %1 -file certs/clientpubkey.cert -keystore certs/trustedclients.keystore -storepass %TRUSTEDCLIENTS_KEYSTORE_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.
