REM #
REM # SM SSL Certificates Creator (server component)
REM #
REM # This batch file facilitates the creation of the SSL certificates
REM # that are needed to setup SSL encryption for Service Manager 7.0x.
REM #
REM # Run this batch file only once to create the certificates for the REM # Service Manager server.
REM #
REM #--------------------------------------------------------------------
cls

@echo off

REM # Openssl settings
REM # 
REM # This batch file uses the openssl.conf file as input for the the
REM # openssl program. All _default values can be set according to your
REM # organisation.
REM #
REM # Only one openssl.conf is needed.
REM #
REM #--------------------------------------------------------------------
set OPENSSL=openssl

REM # Java Settings
REM #
REM # set the JAVA_HOME variable to the installation path of the JRE you
REM # want to use.
REM #
REM #--------------------------------------------------------------------
set JAVA_HOME="C:\Program Files\Java\jre1.5.0_13"
set KEYTOOL=%JAVA_HOME%\bin\keytool

REM # Password settings
REM #
REM # These are the default password settings used by the openssl and
REM # keytool programs. All passwords can be changed, EXCEPT the
REM # CACERT_PASSWD, as this is the default password that the SUN cacert
REM # from the JRE uses!
REM #
REM #--------------------------------------------------------------------
set CAROOT_PASSWD=caroot
set CACERT_PASSWD=changeit
set SERVER_KEYSTORE_PASSWD=serverkeystore
set CLIENT_KEYSTORE_PASSWD=clientkeystore
set TRUSTEDCLIENTS_KEYSTORE_PASSWD=trustedclients

@del /q key
@del /q certs
@del /q crs

@mkdir key
@mkdir certs
@mkdir crs

copy %JAVA_HOME%\lib\security\cacerts %JAVA_HOME%\lib\security\cacerts.orig
copy %JAVA_HOME%\lib\security\cacerts certs\cacerts

REM #-------------------------------------------------------------------
REM # Private Key & Root Certificate generation
REM #-------------------------------------------------------------------

REM create the private key for your private CA
@echo.
@echo ________________________________________________________________________
@echo.
@echo Creating a Self-Signed Certificate (cakey.pem)
@echo.
%OPENSSL% genrsa -des3 -passout pass:%CAROOT_PASSWD% -out key/cakey.pem 2048
@echo.
@echo _________________________________________________________________________
@echo.

REM create the root CA cert
@echo.
@echo _________________________________________________________________________
@echo.
@echo Creating the root ca certificate (mycacert.pem)
@echo.
%OPENSSL% req -new -key key/cakey.pem -x509 -days 1095 -out certs\mycacert.pem -config ./openssl.conf -passin pass:%CAROOT_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.

REM import the certificate into the System-wide keystore
@echo.
@echo _________________________________________________________________________
@echo.
@echo Importing the certificate into the System-wide keystore (cacerts)
@echo.
%KEYTOOL% -import -keystore certs/cacerts -trustcacerts -alias servicemanager -file certs/mycacert.pem -storepass %CACERT_PASSWD% 
@echo.
@echo _________________________________________________________________________
@echo.

copy certs\cacerts %JAVA_HOME%\lib\security



REM #--------------------------------------------------------------------
REM # Server Key & Certficate generation
REM #--------------------------------------------------------------------

REM generate private server key and keystore
@echo.
@echo _________________________________________________________________________
@echo.
@echo Creating the Server keystore (server.keystore)
@echo.
%KEYTOOL% -genkey -alias smserver -keystore key/server.keystore -storepass %SERVER_KEYSTORE_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.

REM generate the server request certificate to be signed using our CA key & cert
@echo.
@echo _________________________________________________________________________
@echo.
@echo Generating the Server request certificate (servercert_request.crs)
@echo.
%KEYTOOL% -certreq -alias smserver -keystore key/server.keystore -file crs/servercert_request.crs -storepass %SERVER_KEYSTORE_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.

REM sign the server request certificate using our CA
@echo.
@echo _________________________________________________________________________
@echo.
@echo Signing the Server request certificate (smservercert.pem)
@echo.
%OPENSSL% x509 -req -days 1095 -in crs/servercert_request.crs -CA certs/mycacert.pem -CAkey key/cakey.pem -CAcreateserial -out certs/smservercert.pem -passin pass:%CAROOT_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.

REM import the server certificate into the keystore
@echo.
@echo _________________________________________________________________________
@echo.
@echo Importing Server certificate into Server keystore
@echo.
%KEYTOOL% -import -trustcacerts -alias smserver -keystore key/server.keystore -file certs/smservercert.pem -storepass %SERVER_KEYSTORE_PASSWD%
@echo.
@echo _________________________________________________________________________
@echo.
